@@ -250,6 +250,108 @@ tmx_is.identified <- function(nVariables, nFactors){
 }
 
 
+# Define generic tmx_show ...
+#' Show matrices of models in a easy-to-learn-from format. 
+#'
+#'
+#' @param x an object e.g. [umxRAM()] [umxMatrix()] from which to show parameters.
+#' @param what legal options are "values" (default), "free", or "labels").
+#' @param show filter on what to show c("all", "free", "fixed").
+#' @param matrices to show  (default is c("S", "A")). "thresholds" in beta.
+#' @param digits precision to report. Default = round to 2 decimal places.
+#' @param na.print How to display NAs (default = "")
+#' @param zero.print How to display 0 values (default = ".")
+#' @param report How to report the results. "html" = open in browser.
+#' @param style The style for the table (Defaults to "paper". Other options are "material_dark", "classic", "classic_2", "minimal", "material")
+#' @param bootstrap_options border etc. Defaults to c("hover", "bordered", "condensed", "responsive")
+#' @param lightable_options Default is "striped"
+#' @param html_font Default is null. Set (e.g. "Optima") to override the style's default font.
+#' @return None
+#' @md
+#' @export
+#' @family Reporting functions
+tmx_show <- function(x, what = c("values", "free", "labels", "nonzero_or_free"), show = c("free", "fixed", "all"), matrices = c("S", "A", "M"), digits = 2, report = c("html", "markdown"), na.print = "", zero.print = ".", html_font = NULL, style = c("paper","material_dark", "classic", "classic_2", "minimal", "material"), bootstrap_options=c("hover", "bordered", "condensed", "responsive"), lightable_options = "striped")  UseMethod("tmx_show", x)
+
+# Define generic RMSEA...
+#' Show matrices of models in a easy-to-learn-from format. 
+#'
+#'
+#' @param x an object e.g. [umxRAM()] [umxMatrix()] from which to show parameters.
+#' @param what legal options are "values" (default), "free", or "labels").
+#' @param show filter on what to show c("all", "free", "fixed").
+#' @param matrices to show  (default is c("S", "A")). "thresholds" in beta.
+#' @param digits precision to report. Default = round to 2 decimal places.
+#' @param na.print How to display NAs (default = "")
+#' @param zero.print How to display 0 values (default = ".")
+#' @param report How to report the results. "html" = open in browser.
+#' @param style The style for the table (Defaults to "paper". Other options are "material_dark", "classic", "classic_2", "minimal", "material")
+#' @param bootstrap_options border etc. Defaults to c("hover", "bordered", "condensed", "responsive")
+#' @param lightable_options Default is "striped"
+#' @param html_font Default is null. Set (e.g. "Optima") to override the style's default font.
+#' @return None
+#' @md
+#' @export
+#' @family Reporting functions
+tmx_show.MxMatrix <- function(x, what = c("values", "free", "labels", "nonzero_or_free"), show = c("free", "fixed", "all"), matrices = c("S", "A", "M"), digits = 2, report = c("html", "markdown"), na.print = "", zero.print = ".", html_font = NULL, style = c("paper","material_dark", "classic", "classic_2", "minimal", "material"), bootstrap_options=c("hover", "bordered", "condensed", "responsive"), lightable_options = "striped"){
+	what   = match.arg(what)
+	show   = match.arg(show)
+	report = match.arg(report)
+	style  = match.arg(style)
+	oldTableFormat = umx_set_table_format(report) # side effect
+	theMatrix = x # just to be clear what object we are processing
+	if(report == "html"){
+		file = paste0(what, theMatrix$name, ".html")
+		# generate the free + value + popover label using kableExtra
+		values = umx_round(theMatrix$values, digits)
+		free   = theMatrix$free
+		labels = theMatrix$labels
+		class  = class(theMatrix)[[1]]
+		values[!free & values ==0] = zero.print
+		
+		tb = kbl(values, caption = paste0(theMatrix$name, " matrix (", class, ")"), format = report)
+		# , paths fixed@0 left blank
+		tb = footnote(kable_input= tb, general = paste0("Fixed cells in gray, free in black, mouse-over to see labels, paths fixed@0 are shown as ", omxQuotes(zero.print)))
+		tb = xmu_style_kable(tb, style = style, html_font = html_font, bootstrap_options= bootstrap_options, lightable_options = lightable_options, full_width = FALSE)
+
+		matCols = dim(values)[[2]]
+		tabCols = kableExtra::magic_mirror(tb)$ncol
+		offset  = (tabCols - matCols)
+		for (thisCol in (1 + offset):tabCols){
+			tb = column_spec(tb, thisCol,
+				# #666666 red= #D7261E green= #26D71E
+				color = ifelse(theMatrix$free[, (thisCol-offset)], "black", "#AAAAAA"),
+				tooltip = labels[, (thisCol-offset)]
+			)
+		}
+		print(tb)
+	} else {
+		if(what == "values"){
+			tmp = data.frame(theMatrix$values)
+			message("\n", "Values of ", omxQuotes(theMatrix), " matrix (0 shown as .):", appendLF = FALSE)
+		}else if(what == "free"){
+			tmp = data.frame(theMatrix$free)
+			message("\n", "Free cells in ", theMatrix$name, " matrix (FALSE shown as .):", appendLF = FALSE)
+		}else if(what == "labels"){
+			tmp = theMatrix$labels
+			if(show == "free"){
+				tmp[theMatrix$free != TRUE] = ""
+			} else if (show == "fixed") {
+				tmp[theMatrix$free == TRUE] = ""
+			}
+			message("\n", show, " labels for ", theMatrix$name, " matrix:", appendLF = FALSE)
+		}else if(what == "nonzero_or_free"){
+			message("99 means parameter is fixed at a non-zero value")
+			values = theMatrix$values
+			Free   = theMatrix$free
+			values[!Free & values !=0] = 99
+			tmp = data.frame(values)
+			message("\n", what, " for ", theMatrix$name, " matrix (0 shown as '.', 99=fixed non-zero value):", appendLF = FALSE)
+		}
+		umx_print(tmp, zero.print = zero.print, na.print = na.print, digits = digits, file= NA, report = report)
+	} # for each matrix
+	umx_set_table_format(oldTableFormat) # side effect
+}
+
 #' Show matrices of RAM models in a easy-to-learn-from format. 
 #'
 #' A great way to learn about models is to look at the matrix contents. `tmx_show` is designed to
@@ -258,7 +360,7 @@ tmx_is.identified <- function(nVariables, nFactors){
 #' 
 #' The user can select which matrices to view, whether to show values, free, and/or labels, and the precision of rounding.
 #'
-#' @param model an [mxModel()] from which to show parameters.
+#' @param x an object e.g. [umxRAM()] [umxMatrix()] from which to show parameters.
 #' @param what legal options are "values" (default), "free", or "labels").
 #' @param show filter on what to show c("all", "free", "fixed").
 #' @param matrices to show  (default is c("S", "A")). "thresholds" in beta.
@@ -276,6 +378,7 @@ tmx_is.identified <- function(nVariables, nFactors){
 #' @references - <https://tbates.github.io>
 #' @md
 #' @examples
+#' \dontrun{
 #' require(umx)
 #' data(demoOneFactor)
 #' manifests = names(demoOneFactor)
@@ -286,13 +389,12 @@ tmx_is.identified <- function(nVariables, nFactors){
 #' 	umxPath(var = "G", fixedAt = 1)
 #' )
 #'
-#' \dontrun{
 #' # =============================================
 #' # = Show smart table on the web (the default) =
 #' # =============================================
 #' tmx_show(m1, report = "html")
 #' tmx_show(m1, what = "free", matrices = "thresholds")
-#' }
+#' tmx_show(m1, zero.print = "-")
 #'
 #' tmx_show(m1, report = "markdown")
 #' tmx_show(m1, digits = 3, report = "markdown")
@@ -300,12 +402,13 @@ tmx_is.identified <- function(nVariables, nFactors){
 #' tmx_show(m1, what = "free"  , report = "markdown")
 #' tmx_show(m1, what = "labels", report = "markdown")
 #' tmx_show(m1, what = "free", matrices = "A", report= "markdown")
-#' tmx_show(m1, zero.print = "-")
+#' }
 #'
-tmx_show <- function(model, what = c("values", "free", "labels", "nonzero_or_free"), show = c("free", "fixed", "all"), matrices = c("S", "A", "M"), digits = 2, report = c("html", "markdown"), na.print = "", zero.print = ".", html_font = NULL, style = c("paper","material_dark", "classic", "classic_2", "minimal", "material"), bootstrap_options=c("hover", "bordered", "condensed", "responsive"), lightable_options = "striped") {
-	if(!umx_is_RAM(model)){
+tmx_show.MxModel <- function(x, what = c("values", "free", "labels", "nonzero_or_free"), show = c("free", "fixed", "all"), matrices = c("S", "A", "M"), digits = 2, report = c("html", "markdown"), na.print = "", zero.print = ".", html_font = NULL, style = c("paper","material_dark", "classic", "classic_2", "minimal", "material"), bootstrap_options=c("hover", "bordered", "condensed", "responsive"), lightable_options = "striped") {
+	if(!umx_is_RAM(x)){
 		stop("Sorry, currently, tmx_show only knows how to display umxRAM models: You gave me a ", class(model)[[1]])
 	}
+	model = x
 	what   = match.arg(what)
 	show   = match.arg(show)
 	report = match.arg(report)
