@@ -21,7 +21,7 @@
 #' \if{latex}{\figure{DoC.pdf}{options: width=7cm}}
 #'
 #' @details
-#' To be added. 
+#' To be added.
 #' @param name The name of the model (defaults to "DOC").
 #' @param var1Indicators variables defining latent trait 1
 #' @param var2Indicators variables defining latent trait 2
@@ -33,6 +33,8 @@
 #' @param intervals Whether to run mxCI confidence intervals (default = FALSE)
 #' @param tryHard Default ('no') uses normal mxRun. "yes" uses mxTryHard. Other options: "ordinal", "search"
 #' @param optimizer Optionally set the optimizer (default NULL does nothing).
+#' @param data = NULL If building the MZ and DZ datasets internally from a complete data set.
+#' @param zyg = "zygosity" (for the data= method of using this function)
 #' @return - [mxModel()] of subclass MxModelDoC
 #' @export
 #' @family Twin Modeling Functions
@@ -73,6 +75,16 @@
 #' b2a   = umxModify(DoC, "b2a", free = TRUE, name = "b2a"); summary(b2a)
 #' Recip = umxModify(DoC, c("a2b", "b2a"), free = TRUE, name = "Recip"); summary(Recip)
 #'
+#' # ==========================================
+#' # = Alternative call with data in one file =
+#' # ==========================================
+#' data(docData)
+#' docData = umx_scale_wide_twin_data(c(var1, var2), docData, sep= "_T")
+#' DoC  = umxDoC(var1= paste0("varA", 1:3), var2= paste0("varB", 1:3),
+#' 	  mzData= c("MZFF", "MZMM"), dzData= c("DZFF", "DZMM"), data = docData
+#' )
+#'
+#' # Usage example (won\t run)
 #' var1 = paste0("SOS", 1:8)
 #' var2 = paste0("Vocab", 1:10)
 #' Chol = umxDoC(var1= var1, var2= var2,mzData= mzData, dzData= dzData, causal= FALSE)
@@ -81,14 +93,26 @@
 #' b2a  = umxModify(DoC, "b2a", free = TRUE, name = "b2a")
 #' Recip= umxModify(DoC, c("a2b", "b2a"), free = TRUE, name = "Recip")
 #' umxCompare(Chol, c(a2b, b2a, Recip))
-#'
 #' }
 #' 
-umxDoC <- function(name = "DoC", var1Indicators, var2Indicators, mzData= NULL, dzData= NULL, sep = "_T", causal= TRUE, autoRun = getOption("umx_auto_run"), intervals = FALSE, tryHard = c("no", "yes", "ordinal", "search"), optimizer = NULL) {
+umxDoC <- function(name = "DoC", var1Indicators, var2Indicators, mzData= NULL, dzData= NULL, sep = "_T", causal= TRUE, autoRun = getOption("umx_auto_run"), intervals = FALSE, tryHard = c("no", "yes", "ordinal", "search"), optimizer = NULL, data = NULL, zyg = "zygosity") {
 	# TODO: umxDoC add some name checking to avoid variables like "a1"
 	if(name == "DoC"){name = ifelse(causal, "DoC", "Chol")}
 	tryHard = match.arg(tryHard)
 	umx_check(is.logical(causal), "stop", "causal must be TRUE or FALSE")
+		
+	if (!is.null(data)) {
+	  if ("tbl" %in% class(data)) {
+	    data = as.data.frame(data)
+	  }
+	  mzData = data[data[, zyg] %in% ifelse(is.null(mzData),"MZ", mzData), ]
+	  dzData = data[data[, zyg] %in% ifelse(is.null(dzData),"DZ", dzData), ]
+	} else {
+	  if ("tbl" %in% class(mzData)) {
+	    mzData = as.data.frame(mzData)
+	    dzData = as.data.frame(dzData)
+	  }
+	}
 	nSib    = 2 # Number of siblings in a twin pair.
 	nLat    = 2 # 2 latent variables
 
@@ -197,9 +221,8 @@ umxDoC <- function(name = "DoC", var1Indicators, var2Indicators, mzData= NULL, d
 #' Plot a Direction of Causation Model.
 #'
 #' Summarize a fitted model returned by [umxDoC()]. Can control digits, report comparison model fits,
-#' optionally show the *Rg* (genetic and environmental correlations), and show confidence intervals. the report parameter allows
-#' drawing the tables to a web browser where they may readily be pasted into, e.g. Word.
-#'
+#' optionally show the *Rg* (genetic and environmental correlations), and show confidence intervals.
+#' *note*: `std` is not implemented as yet.
 #' See documentation for other umx models here: [umxSummary()].
 #' 
 #' @aliases plot.MxModelDoC
@@ -248,7 +271,7 @@ umxDoC <- function(name = "DoC", var1Indicators, var2Indicators, mzData= NULL, d
 #' plot(a2b)
 #' 
 #' }
-umxPlotDoC <- function(x = NA, means = FALSE, std = TRUE, digits = 2, showFixed = TRUE, file = "name", format = c("current", "graphviz", "DiagrammeR"), SEstyle = FALSE, strip_zero = FALSE, ...) {
+umxPlotDoC <- function(x = NA, means = FALSE, std = FALSE, digits = 2, showFixed = TRUE, file = "name", format = c("current", "graphviz", "DiagrammeR"), SEstyle = FALSE, strip_zero = FALSE, ...) {
 	message("beta code")
 	# 1. ✓ draw latents
 	# 2. ✓ draw manifests,
@@ -260,7 +283,7 @@ umxPlotDoC <- function(x = NA, means = FALSE, std = TRUE, digits = 2, showFixed
 	format = match.arg(format)
 	model = x # just to emphasise that x has to be a model 
 	umx_check_model(model, "MxModelDoC", callingFn = "umxPlotDoC")
-	
+
 	if(std){
 		message("I'm sorry Dave, no std for DoC yet ;-(")
 		# model = xmu_standardize_DoC(model)
@@ -293,9 +316,9 @@ umxPlotDoC <- function(x = NA, means = FALSE, std = TRUE, digits = 2, showFixed
 	# [1,] "a2a" "b2a"
 	# [2,] "a2b" "b2b"
 	out = xmu_dot_mat2dot(model$top$beta, cells = "any", toLabel = selLat, from = "cols", fromType = "latent", showFixed = showFixed, p = out, fromLabel=selLat)
-	# Process "expMean" 1 * nVar matrix
+
+	# Process "expMean" 1 * nVar matrix # from = "one"; target = selDVs[c]
 	if(means){
-		# from = "one"; target = selDVs[c]
 		out = xmu_dot_mat2dot(model$top$expMean, cells = "left", toLabel = selDVs, from = "rows", fromLabel = "one", fromType = "latent", showFixed = showFixed, p = out)
 	}
 	preOut  = xmu_dot_define_shapes(latents = out$latents, manifests = selDVs[1:nVar])
@@ -305,19 +328,16 @@ umxPlotDoC <- function(x = NA, means = FALSE, std = TRUE, digits = 2, showFixed
 
 	label = model$name
 	splines = "FALSE"
-
 	digraph = paste0(
 		"digraph G {\n\t",
 		'label="', label, '";\n\t',
 		"splines = \"", splines, "\";\n",
 		preOut,
-		top, 
-		same,
-		bottom,
-		out, "\n}"
+		out$str,
+		"\n", top, same, bottom, "\n}"
 	)
 	
-	message("\n?umxPlotDoC options: std=, means=, digits=, strip_zero=, file=, min=, max =")
+	cat("\n?umxPlotDoC options: std=, means=, digits=, strip_zero=, file=, min=, max =")
 	if(format != "current"){ umx_set_plot_format(format) }
 	xmu_dot_maker(model, file, digraph, strip_zero = strip_zero)
 }
